@@ -21,7 +21,7 @@ Schema:
       "foo":            string,
       "_jc_meta":                    # This object only exists if using -qq or ignore_exceptions=True
         {
-          "success":    booean,      # true if successfully parsed, false if error
+          "success":    boolean,     # true if successfully parsed, false if error
           "error":      string,      # exists if "success" is false
           "line":       string       # exists if "success" is false
         }
