@@ -60,7 +60,7 @@ Schema:
       "epoch_utc":                         integer      # aware timestamp if -t flag is used and UTC TZ
       "_jc_meta":                                       # This object only exists if using -qq or ignore_exceptions=True
         {
-          "success":                       booean,      # true if successfully parsed, false if error
+          "success":                       boolean,     # true if successfully parsed, false if error
           "error":                         string,      # exists if "success" is false
           "line":                          string       # exists if "success" is false
         }
